@@ -3,8 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': '/usr/bin/ar',
@@ -19,16 +19,16 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'aarch64-unknown-openbsd7.3',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.3',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+ 'CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -pipe -g',
+ 'CONFIGURE_CFLAGS': '-O2 -pipe',
  'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c11 '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
@@ -46,7 +46,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
                 "'--infodir=/usr/local/info' '--localstatedir=/var' "
                 "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe -g' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
                 "'CPPFLAGS=-I/usr/local/include' "
                 "'TCLTK_CFLAGS=-I/usr/local/include/tcl8.6 "
                 "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
@@ -54,16 +54,15 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.11.3/Python-3.11.3/coverage.info',
+ 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.11.4/Python-3.11.4/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.11.3/Python-3.11.3/lcov-report',
+ 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.11.4/Python-3.11.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                   '-DHAVE_UINT128_T=1',
+ 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
@@ -236,8 +235,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 1,
  'HAVE_GDBM_NDBM_H': 0,
@@ -305,7 +304,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -593,17 +592,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'aarch64-unknown-openbsd7.3',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.3',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.11 '
                    '/usr/local/include/python3.11',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.11',
- 'INSTALL': '/build/tmp/pobj//Python-3.11.3/bin/install -c',
- 'INSTALL_DATA': '/build/tmp/pobj//Python-3.11.3/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.11.3/bin/install -c  -m 755',
- 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.11.3/bin/install -c -m 755',
- 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.11.3/bin/install -c -m 755',
+ 'INSTALL': '/build/tmp/pobj//Python-3.11.4/bin/install -c',
+ 'INSTALL_DATA': '/build/tmp/pobj//Python-3.11.4/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.11.4/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.11.4/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.11.4/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.11.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -617,8 +616,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/local/lib/python3.11',
  'LIBDIR': '/usr/local/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g '
-                    '-flto -g -std=c11 -Werror=implicit-function-declaration '
+ 'LIBEXPAT_CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                    '-std=c11 -Werror=implicit-function-declaration '
                     '-fvisibility=hidden -I/usr/local/include '
                     '-fprofile-instr-use=code.profclangd -I./Include/internal '
                     '-I. -I./Include -I/usr/local/include -fPIC -fPIC',
@@ -627,13 +626,12 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBFFI_INCLUDEDIR': '/usr/local/include',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe '
-                    '-g -O2 -pipe -g -flto -g -std=c11 '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-I/usr/local/include -fprofile-instr-use=code.profclangd '
-                    '-I./Include/internal -I. -I./Include -I/usr/local/include '
-                    '-fPIC -fPIC',
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
+                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -I/usr/local/include '
+                    '-fprofile-instr-use=code.profclangd -I./Include/internal '
+                    '-I. -I./Include -I/usr/local/include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -779,8 +777,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CTYPES_TEST_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
+                           '-DANSI=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -888,7 +886,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -pipe -g  -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -924,43 +922,42 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 '
-                             '-pipe -g -flto -g -std=c11 '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+                             '-flto -g -std=c11 '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -I/usr/local/include '
                              '-fprofile-instr-use=code.profclangd '
                              '-I./Include/internal -I. -I./Include '
                              '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+ 'PY_CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-flto -g -std=c11 -Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
                      '-fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g '
-                   '-flto -g -std=c11 -Werror=implicit-function-declaration '
+ 'PY_CORE_CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                   '-std=c11 -Werror=implicit-function-declaration '
                    '-fvisibility=hidden -I/usr/local/include '
                    '-fprofile-instr-use=code.profclangd -I./Include/internal '
                    '-I. -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
-                    '-L/build/tmp/pobj//Python-3.11.3/Python-3.11.3 '
+                    '-L/build/tmp/pobj//Python-3.11.4/Python-3.11.4 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-flto -g -L/build/tmp/pobj//Python-3.11.3/Python-3.11.3 '
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/build/tmp/pobj//Python-3.11.4/Python-3.11.4 '
                       '-L/usr/local/lib/',
  'PY_LDFLAGS_NOLTO': '-L/usr/local/lib/ -flto=thin '
-                     '-L/build/tmp/pobj//Python-3.11.3/Python-3.11.3 '
+                     '-L/build/tmp/pobj//Python-3.11.4/Python-3.11.4 '
                      '-L/usr/local/lib/',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe '
-                        '-g -flto -g -std=c11 '
-                        '-Werror=implicit-function-declaration '
+ 'PY_STDMODULE_CFLAGS': '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto '
+                        '-g -std=c11 -Werror=implicit-function-declaration '
                         '-fvisibility=hidden -I/usr/local/include '
                         '-fprofile-instr-use=code.profclangd '
                         '-I./Include/internal -I. -I./Include '
@@ -975,7 +972,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.3/Python-3.11.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.4/Python-3.11.4',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -987,18 +984,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-311',
@@ -1019,10 +1016,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.3/Python-3.11.3 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.4/Python-3.11.4 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.3/Python-3.11.3 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.11.4/Python-3.11.4 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1051,10 +1048,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/tmp/pobj/Python-3.11.3/Python-3.11.3',
- 'abs_srcdir': '/build/tmp/pobj/Python-3.11.3/Python-3.11.3',
+ 'abs_builddir': '/build/tmp/pobj/Python-3.11.4/Python-3.11.4',
+ 'abs_srcdir': '/build/tmp/pobj/Python-3.11.4/Python-3.11.4',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
